@@ -226,8 +226,6 @@ let _ =
   network.op_network_connected <- (fun _ -> false);
   network.op_network_is_enabled <- (fun _ -> raise IgnoreNetwork);
   network.op_network_update_options <- (fun _ -> raise IgnoreNetwork);
-  (* op_network_info defined twice ?? *)
-  network.op_network_info <- (fun _ -> raise Not_found);
   network.op_network_info <- (fun n ->
       {
         network_netnum = network.network_num;
