@@ -1295,10 +1295,10 @@ let old_print_search buf o results =
                 match r.result_names with
                   [] -> ()
                 | name :: names ->
-                    Printf.bprintf buf "%s\n" (shorten name !!max_name_len);
+                    Printf.bprintf buf "%s\n" (shorten name !!max_result_name_len);
                     List.iter (fun s ->
                         if use_html_mods o then Printf.bprintf buf "\\<BR\\>";
-                        Printf.bprintf buf "       %s\n" (shorten s !!max_name_len)
+                        Printf.bprintf buf "       %s\n" (shorten s !!max_result_name_len)
                     ) names;
               end;
               if r.result_done then
@@ -1630,7 +1630,7 @@ let print_results stime buf o results =
                           if o.conn_output = HTML then Buffer.add_string buf "\\</table\\>\n";
 
                           Buffer.contents buf
-                    ) !!max_name_len)
+                    ) !!max_result_name_len)
                   (if o.conn_output = HTML then
                       begin
                         if !!html_mods then "\\</a\\>\\</td\\>"
@@ -1995,6 +1995,7 @@ let runinfo html buf o =
 	 (Autoconf.donkey = "yes" && !!enable_overnet, "Overnet");
 	 (Autoconf.donkey = "yes" && !!enable_kademlia, "Kademlia");
 	 (Autoconf.bittorrent = "yes" && !!enable_bittorrent, "BitTorrent");
+	 (Autoconf.direct_connect = "yes" && !!enable_directconnect, "DirectConnect");
 	 (Autoconf.fasttrack = "yes" && !!enable_fasttrack, "Fasttrack");
 	 (Autoconf.gnutella = "yes" && !!enable_gnutella, "Gnutella");
 	 (Autoconf.gnutella2 = "yes" && !!enable_gnutella2, "G2");
