@@ -169,7 +169,7 @@ let decode_torrent s =
                             announce_list := !next_urls @ !announce_list
                           end
                         else
-                          announce_list := List.hd !next_urls :: !announce_list
+                          announce_list := (try List.hd !next_urls with _ -> "") :: !announce_list
                     | _ ->
                         lprintf_nl "[BT] unknown field in announce list"
                     ) list;
@@ -285,7 +285,6 @@ let decode_torrent s =
     | None -> Charset.safe_convert !file_encoding !file_name
     | Some name -> name
   in
-  assert (!announce <> "");
   assert (real_file_name <> "");
   assert (!file_piece_size <> zero);
   assert (!file_pieces <> "");
