@@ -60,6 +60,7 @@ type brand =
 | Brand_bittornado
 | Brand_bittorrentx
 | Brand_btplus
+| Brand_bitrocket
 | Brand_btslave
 | Brand_btugaxp
 | Brand_burst
@@ -104,6 +105,25 @@ type brand =
 | Brand_retriever
 | Brand_osprey
 | Brand_rufus
+| Brand_tribler
+| Brand_cachelogic
+| Brand_electricsheep
+| Brand_qbittorrent
+| Brand_qt4
+| Brand_uleecher
+| Brand_flashget
+| Brand_xtorrent
+| Brand_limewire
+| Brand_btpd
+| Brand_btyrant
+| Brand_ares
+| Brand_bitpump
+| Brand_deluge
+| Brand_btuga
+| Brand_tuotu
+| Brand_xunlei
+| Brand_foxtorrent
+| Brand_bitflu
 
 let brand_list = [ 
    ( Brand_unknown          , "unknown"                , "unk" ) ;
@@ -119,6 +139,7 @@ let brand_list = [
    ( Brand_bittornado       , "BitTornado"             , "trn" ) ;
    ( Brand_bittorrentx      , "BitTorrent X"           , "btx" ) ;
    ( Brand_btplus           , "BitTorrent Plus!"       , "plu" ) ;
+   ( Brand_bitrocket        , "BitRocket"              , "roc" ) ;
    ( Brand_btslave          , "BTSlave"                , "sla" ) ;
    ( Brand_btugaxp          , "BTugaXP"                , "uga" ) ;
    ( Brand_burst            , "Burst !"                , "brs" ) ;
@@ -163,6 +184,25 @@ let brand_list = [
    ( Brand_retriever        , "Retriever"              , "ret" ) ;
    ( Brand_osprey           , "Osprey permaseed"       , "osp" ) ;
    ( Brand_rufus            , "Rufus"                  , "ruf" ) ;
+   ( Brand_tribler          , "Tribler"                , "trb" ) ;
+   ( Brand_cachelogic       , "CacheLogic"             , "cl"  ) ;
+   ( Brand_electricsheep    , "Electric sheep"         , "els" ) ;
+   ( Brand_qbittorrent      , "qBittorrent"            , "qbt" ) ;
+   ( Brand_qt4              , "QT4"                    , "qt4" ) ;
+   ( Brand_uleecher         , "uLeecher!"              , "ul!" ) ;
+   ( Brand_flashget         , "FlashGet"               , "flg" ) ;
+   ( Brand_xtorrent         , "Xtorrent"               , "xto" ) ;
+   ( Brand_limewire         , "LimeWire"               , "lwi" ) ;
+   ( Brand_btpd             , "BT Protocol Daemon"     , "bpd" ) ;
+   ( Brand_btyrant          , "BitTyrant"              , "bty" ) ;
+   ( Brand_ares             , "Ares"                   , "are" ) ;
+   ( Brand_bitpump          , "BitPump"                , "bpu" ) ;
+   ( Brand_deluge           , "Deluge"                 , "del" ) ;
+   ( Brand_btuga            , "BTuga Revolution"       , "btr" ) ;
+   ( Brand_tuotu            , "Tuotu"                  , "tuo" ) ;
+   ( Brand_xunlei           , "XunLei"                 , "xun" ) ;
+   ( Brand_foxtorrent       , "FoxTorrent"             , "fox" ) ;
+   ( Brand_bitflu           , "BitFlu"                 , "flu" ) ;
   ] 
 
 let brand_count = List.length brand_list
@@ -176,12 +216,19 @@ let brand_to_string_short brand =
 let brand_to_int brand = 
   find_int_of_brand brand brand_list
 
+type tracker_status =
+  Enabled
+| Disabled of string
+| Disabled_mld of string
+| Disabled_failure of (int * string)
+
 type client = {
     client_client : client CommonClient.client_impl;
     mutable client_file : file;
     mutable client_connection_control : connection_control;
     mutable client_sock : tcp_connection;
     mutable client_host : Ip.t * int;
+    mutable client_country_code : int option;
     mutable client_chunks : (int64 * int64) list;
     mutable client_uploader : CommonSwarming.uploader option;
     mutable client_ranges_sent : (int64 * int64 * CommonSwarming.range) list;
@@ -205,9 +252,11 @@ type client = {
     mutable client_allowed_to_write : int64;
     mutable client_upload_rate : Rate.t;
     mutable client_downloaded_rate :  Rate.t;
-    mutable client_downloaded : int64;
-    mutable client_uploaded : int64;
-    mutable client_optimist_time : int;
+    mutable client_total_downloaded : int64;
+    mutable client_total_uploaded : int64;
+    mutable client_session_downloaded : int64;
+    mutable client_session_uploaded : int64;
+    mutable client_connect_time : int;
 
     mutable client_blocks_sent : int list;
     mutable client_good : bool;
@@ -218,6 +267,13 @@ type client = {
     mutable client_incoming : bool;
     mutable client_registered_bitfield : bool;
     mutable client_last_optimist : int;
+
+    mutable client_dht : bool;
+    mutable client_cache_extension : bool;
+    mutable client_fast_extension : bool;
+    mutable client_utorrent_extension : bool;
+    mutable client_azureus_messaging_protocol : bool;
+
   }
 
 and tracker_info = {
@@ -233,7 +289,7 @@ and tracker_info = {
     mutable tracker_torrent_last_dl_req : int;
     mutable tracker_id : string;
     mutable tracker_key : string;
-    mutable tracker_enabled : bool;
+    mutable tracker_status : tracker_status;
   }
 
 and file = {
