@@ -155,7 +155,7 @@ module Make(Doc : sig
               | Some node -> node
               | Filtered _ -> 
                   Doc.filter doc true;
-                  lprintf "doc filtered"; lprint_newline (); 
+                  lprintf_nl "doc filtered";
                   raise Not_found
             else
               add_char node c
@@ -318,4 +318,4 @@ module Make(Doc : sig
   
   
 module FullMake (Doc : Indexer.Doc) = Indexer.FullMake (Doc ) (Make)
-  
\ No newline at end of file
+  
