@@ -341,7 +341,7 @@ module Make(M: sig
     
     let file s =
       let digest = String.create hash_length in
-      let file_size = Unix32.getsize s false in
+      let file_size = Unix32.getsize s in
       unsafe_file digest s file_size;
       digest
     
@@ -469,12 +469,10 @@ module Tiger = Make(struct
         "tiger_unsafe_string"
         
       let unsafe_file digest filename = 
-        Printf2.lprintf "Tiger.unsafe_file not implemented\n";
-        exit 70
+        failwith "Tiger.unsafe_file not implemented"
         
-      let digest_subfile digest fd pos len = 
-        Printf2.lprintf "Tiger.digest_subfile not implemented\n";
-        exit 70
+      let digest_subfile _ _ _ _ = 
+        failwith "Tiger.digest_subfile not implemented"
     
       module Base = Base32
         
@@ -489,7 +487,7 @@ module PreTigerTree = Make(struct
         "tigertree_unsafe64_fd"
       
       let unsafe_file digest filename file_size = 
-        let fd = Unix32.create_diskfile filename [Unix.O_RDONLY] 0o444 in
+        let fd = Unix32.create_diskfile filename false in
         Unix32.apply_on_chunk fd Int64.zero file_size 
           (fun fd pos ->
             digest_subfile digest fd pos file_size)
